@@ -49,12 +49,6 @@ class Augmentation:
         # 1. if no boxes, then directly return
         if lines == []:
             return -1
-        
-        # we remove small boxes aready in previous steps thus no need to check here anymore
-        for line in lines:
-            cls, xc, yc, w, h = line.split(' ')
-            xc, yc, h, w = float(xc), float(yc), float(h), float(w)
-            xc, yc, h, w = int(width*xc), int(height*yc), int(height*h), int(width*w)
 
         # ---step2: store boxes into list
         # 2 things are done here: 1. write original boxes into new file, 2. store original boxes into list
@@ -79,6 +73,9 @@ class Augmentation:
             y2 = min(height, y1+h)
             x2 = min(width, x1+w)
             
+            if y1 <= margin:
+                continue
+            
             existing_box.append([cls, x1, y1, x2, y2]) # x1y1x2y2
 
         # ---step 3: augmentation
@@ -101,6 +98,9 @@ class Augmentation:
                         candidate_y = np.random.randint(margin, height-h) if height-h!=0 else 0
                     else:
                         candidate_y = np.random.randint(0, margin-h) if margin-h!=0 else 0
+                        
+                    if candidate_x == candidate_y == 0: # both are 0, no need to try anymore
+                        break
 
                     res = [] # list used for checking if candidate x and y are valid or not
                     val_cnt+=1
@@ -167,7 +167,6 @@ class Augmentation:
                                       mask_top=mask_top,
                                       quit=quit)
                 if status == -1: # no label or invalid for augmentation
-                    invalid += 1
                     shutil.copy2(i, savepath_img + '{}.jpg'.format(name))
                     shutil.copy2(l, savepath_lbl + '{}.txt'.format(name))
                     break
